@@ -22,9 +22,9 @@
 uint32_t options = BO_NONE;
 char desc[] = "MP4 video encoder";
 
-#define FFMPEG_CHECK         "ffmpeg -h >/dev/null 2>&1"
-#define MP4_FFMPEG_CMD       "ffmpeg -loglevel quiet -re -framerate %d -vcodec ppm -f image2pipe -i pipe: -vcodec libx264 -pix_fmt yuv420p -r %d -vsync cfr %s"
-#define MP4_FFMPEG_CMD_AUDIO "ffmpeg -loglevel quiet -re -framerate %d -vcodec ppm -f image2pipe -i pipe: -i %s -vcodec libx264 -pix_fmt yuv420p -r %d -vsync cfr %s"
+#define FFMPEG_CHECK         "/usr/bin/ffmpeg -h >/dev/null 2>&1"
+#define MP4_FFMPEG_CMD       "/usr/bin/ffmpeg -y -loglevel quiet -re -framerate %d -vcodec ppm -f image2pipe -i pipe: -vcodec libx264 -pix_fmt yuv420p -r %d -vsync cfr %s"
+#define MP4_FFMPEG_CMD_AUDIO "/usr/bin/ffmpeg -y -loglevel quiet -re -framerate %d -vcodec ppm -f image2pipe -i pipe: -i %s -vcodec libx264 -pix_fmt yuv420p -r %d -vsync cfr %s"
 
 
 #define DIRECTORY      "/mp4/"
@@ -76,14 +76,16 @@ open_mp4(Context_t *ctx)
   if (NULL == audio_file) {
     audio_file = getenv("LEBINIOU_SNDFILE");
   }
-  /* strdup() is needed because LEBINIOU_SNDFILE gets modified in video_filename() */
+  // strdup() is needed because LEBINIOU_SNDFILE gets modified in video_filename()
   char *audio = (NULL != audio_file) ? strdup(audio_file) : NULL;
-  mp4_filename = video_filename();
-  char *cmd;
+  char *env = getenv("LEBINIOU_MP4_FILENAME");
+  // strdup() is needed because mp4_filename is xfreed()
+  mp4_filename = (NULL != env) ? strdup(env) : video_filename();
+  gchar *cmd;
 
   if (NULL != audio) {
     cmd = g_strdup_printf(MP4_FFMPEG_CMD_AUDIO, max_fps, audio, max_fps, mp4_filename);
-    free(audio);
+    xfree(audio);
   } else {
     cmd = g_strdup_printf(MP4_FFMPEG_CMD, max_fps, max_fps, mp4_filename);
   }
@@ -102,6 +104,8 @@ create(Context_t *ctx)
 {
   if (check_command(FFMPEG_CHECK) == -1) {
     printf("[!] %s: ffmpeg binary not found, can't create video\n", __FILE__);
+
+    return 0;
   } else if (encoding) {
     open_mp4(ctx);
   }
@@ -117,6 +121,7 @@ destroy(Context_t *ctx)
     if (-1 == pclose(mp4)) {
       xperror("pclose");
     }
+  xfree(mp4_filename);
 }
 
 
