@@ -148,7 +148,7 @@ biniou_new(const char *datadir, const char *pluginsdir,
     Context_init_playlist(context);
   }
 
-  b_timer_set_mode(use_hard_timers ? BT_HARD : BT_SOFT);
+  Timer_set_mode(use_hard_timers ? BT_HARD : BT_SOFT);
 
   VERBOSE(printf("[+] Biniou initialized\n"));
 }
