@@ -39,7 +39,7 @@ ui_thread(void *attr)
                               "ping", json_pack("{sisisi}",
                                   "fps", (uint16_t)Context_fps(ctx),
                                   "max_fps", max_fps,
-                                  "uptime", (uint64_t)b_timer_elapsed(ctx->timer)));
+                                  "uptime", (uint64_t)Timer_elapsed(ctx->timer)));
 #if ULFIUS_VERSION_NUMBER < 0x020609
       char *payload = json_dumps(res, 0);
 #endif
