@@ -51,7 +51,7 @@ char *audio_file = NULL;
 // start mp4 encoding automatically
 uint8_t  encoding = 0;
 
-int override_webcam = 0;
+uint8_t override_webcam = 0;
 uint8_t usage_statistics = 1;
 uint8_t enable_osd = 0;
 uint8_t launch_browser = 1;
