@@ -21,20 +21,6 @@
 #include "image_8bits.h"
 
 
-Image8_t *
-Image8_new()
-{
-  Image8_t *p = NULL;
-
-  p = xcalloc(1, sizeof(Image8_t));
-
-  p->id = -1;
-  p->buff = Buffer8_new();
-
-  return p;
-}
-
-
 Image8_t *
 Image8_new_default()
 {
@@ -49,19 +35,6 @@ Image8_new_default()
 }
 
 
-void
-Image8_delete(Image8_t *p)
-{
-  xfree(p->name);
-  xfree(p->dname);
-
-  if (p->buff) {
-    Buffer8_delete(p->buff);
-  }
-  xfree(p);
-}
-
-
 int
 Image8_load_any(Image8_t *img, const char *file)
 {
@@ -117,24 +90,6 @@ Image8_load(Image8_t *img, const uint32_t id, const char *dir, const char *filen
 }
 
 
-void
-Image8_copy(const Image8_t *from, Image8_t *to)
-{
-  assert(NULL != from);
-  assert(NULL != to);
-
-  assert(NULL != from->name);
-
-  xfree(to->name);
-
-  to->name = strdup(from->name);
-
-  to->id = from->id;
-
-  Buffer8_copy(from->buff, to->buff);
-}
-
-
 void
 Image8_to_PNG(const Image8_t *img, uint8_t **data, uint32_t *datalen)
 {
