@@ -22,11 +22,36 @@
 #include "images.h"
 #include "colormaps.h"
 
+#define SAVEDIR ".lebiniou/sequences"
+
 #define SEQ_VERSION_MIN 0
 #define SEQ_VERSION_MAX 1
 
 // #define DEBUG_SEQUENCE_V0
 
+char *sequences_dir = NULL; // Sequences directory
+
+
+const char *
+Sequences_get_dir()
+{
+  if (NULL == sequences_dir) {
+    const gchar *home_dir;
+
+    home_dir = g_get_home_dir();
+    sequences_dir = g_strdup_printf("%s/%s", home_dir, SAVEDIR);
+#ifdef DEBUG
+    printf("[i] Setting default sequences directory: '%s'\n", sequences_dir);
+#endif
+  } else {
+#ifdef DEBUG
+    printf("[i] Using sequences directory: '%s'\n", sequences_dir);
+#endif
+  }
+
+  return sequences_dir;
+}
+
 
 Sequence_t *
 Sequence_from_json(json_t *parsed_json)
