@@ -20,7 +20,7 @@
 #include "globals.h"
 #include "sequences.h"
 
-char *sequences_dir = NULL; // Sequences directory
+extern char *sequences_dir;
 
 
 void
@@ -91,29 +91,6 @@ Sequences_delete()
 }
 
 
-/* TODO un g_list_find */
-GList *
-Sequences_find(const uint32_t id)
-{
-  GList *tmp;
-
-  assert(NULL != sequences);
-  tmp = sequences->seqs;
-
-  while (NULL != tmp) {
-    Sequence_t *s = (Sequence_t *)tmp->data;
-
-    if (s->id == id) {
-      return tmp;
-    }
-
-    tmp = g_list_next(tmp);
-  }
-
-  return NULL;
-}
-
-
 GList *
 Sequences_find_by_name(const char *name)
 {
@@ -141,26 +118,3 @@ Sequences_set_dir(char *dir)
 {
   sequences_dir = dir;
 }
-
-
-#define SAVEDIR ".lebiniou/sequences"
-
-const char *
-Sequences_get_dir()
-{
-  if (NULL == sequences_dir) {
-    const gchar *home_dir;
-
-    home_dir = g_get_home_dir();
-    sequences_dir = g_strdup_printf("%s/%s", home_dir, SAVEDIR);
-#ifdef DEBUG
-    printf("[i] Setting default sequences directory: '%s'\n", sequences_dir);
-#endif
-  } else {
-#ifdef DEBUG
-    printf("[i] Using sequences directory: '%s'\n", sequences_dir);
-#endif
-  }
-
-  return sequences_dir;
-}
